@@ -97,6 +97,9 @@ DGifOpenFileHandle(int FileHandle, int *Error)
         free((char *)GifFile);
         return NULL;
     }
+
+    /*@i1@*/memset(Private, '\0', sizeof(GifFilePrivateType));
+
 #ifdef _WIN32
     _setmode(FileHandle, O_BINARY);    /* Make sure it is in binary mode. */
 #endif /* _WIN32 */
@@ -179,6 +182,7 @@ DGifOpen(void *userData, InputFunc readFunc, int *Error)
         free((char *)GifFile);
         return NULL;
     }
+    /*@i1@*/memset(Private, '\0', sizeof(GifFilePrivateType));
 
     GifFile->Private = (void *)Private;
     Private->FileHandle = 0;
@@ -764,7 +768,7 @@ DGifSetupDecompress(GifFileType *GifFile)
     BitsPerPixel = CodeSize;
 
     /* this can only happen on a severely malformed GIF */
-    if (BitsPerPixel > 8 || Private->RunningBits > 32) {
+    if (BitsPerPixel > 8) {
 	GifFile->Error = D_GIF_ERR_READ_FAILED;	/* somewhat bogus error code */
 	return GIF_ERROR;    /* Failed to read Code size. */
     }
